depend library

Classes

DependencyContainer
An abstract class that serves as a foundation for managing dependencies in a hierarchical and structured way.
DependencyFactory<T extends DependencyContainer>
An abstract class representing a factory responsible for creating instances of a specific type of DependencyContainer.
DependencyProvider<T extends DependencyContainer>
A widget that provides a DependencyContainer (or its subclass) to its subtree.
DependencyScope<T extends DependencyContainer, F extends DependencyFactory<T>>
A widget that initializes and provides a DependencyContainer to its subtree.
LazyFutureGet<T>
A simple class for lazy initialization of dependencies that are created asynchronously. This class allows you to define a factory function that returns a Future, which will be awaited only when the instance is accessed for the first time. Example usage:
LazyGet<T>
A simple class for lazy initialization of dependencies. This class allows you to define a factory function that will be called only when the instance is accessed for the first time. Example usage:

Extensions

DependencyContext on BuildContext
An extension on BuildContext that provides convenient methods for accessing dependencies registered via DependencyProvider.